@@ -6,8 +6,10 @@ import (
 	"fmt"
 	"os"
 
-	"github.com/variantdev/vals"
 	"gopkg.in/yaml.v3"
+
+	"github.com/helmfile/vals"
+	"github.com/helmfile/vals/pkg/log"
 )
 
 var (
@@ -25,6 +27,7 @@ Available Commands:
   eval		Evaluate a JSON/YAML document and replace any template expressions in it and prints the result
   exec		Populates the environment variables and executes the command
   env		Renders environment variables to be consumed by eval or a tool like direnv
+  get       Evaluate a string value passed as the first argument and replace any expressiosn in it and prints the result
   ksdecode	Decode YAML document(s) by converting Secret resources' "data" to "stringData" for use with "vals eval"
   version	Print vals version
 
@@ -71,6 +74,7 @@ func main() {
 	flag.Usage = flagUsage
 
 	CmdEval := "eval"
+	CmdGet := "get"
 	CmdExec := "exec"
 	CmdEnv := "env"
 	CmdKsDecode := "ksdecode"
@@ -86,8 +90,12 @@ func main() {
 		evalCmd := flag.NewFlagSet(CmdEval, flag.ExitOnError)
 		f := evalCmd.String("f", "-", "YAML/JSON file to be evaluated. When set to \"-\", vals reads from STDIN")
 		o := evalCmd.String("o", "yaml", "Output type which is either \"yaml\" or \"json\"")
+		evalCmd.BoolVar(&log.Silent, "s", false, "Silent mode")
 		e := evalCmd.Bool("exclude-secret", false, "Leave secretref+<uri> as-is and only replace ref+<uri>")
-		evalCmd.Parse(os.Args[2:])
+		err := evalCmd.Parse(os.Args[2:])
+		if err != nil {
+			fatal("%v", err)
+		}
 
 		nodes := readNodesOrFail(f)
 
@@ -110,14 +118,39 @@ func main() {
 		}
 
 		writeOrFail(o, res)
+	case CmdGet:
+		getCmd := flag.NewFlagSet(CmdGet, flag.ExitOnError)
+		getCmd.BoolVar(&log.Silent, "s", false, "Silent mode")
+		err := getCmd.Parse(os.Args[2:])
+		if err != nil {
+			fatal("%v", err)
+		}
+
+		code := getCmd.Arg(0)
+		if code == "" {
+			fatal("The first argument of the get command is required")
+		}
+
+		v, err := vals.Get(code)
+		if err != nil {
+			fatal("%v", err)
+		}
+
+		_, err = os.Stdout.WriteString(v)
+		if err != nil {
+			fatal("%v", err)
+		}
 	case CmdExec:
 		execCmd := flag.NewFlagSet(CmdExec, flag.ExitOnError)
 		f := execCmd.String("f", "", "YAML/JSON file to be loaded to set envvars")
-		execCmd.Parse(os.Args[2:])
+		err := execCmd.Parse(os.Args[2:])
+		if err != nil {
+			fatal("%v", err)
+		}
 
 		m := readOrFail(f)
 
-		err := vals.Exec(m, execCmd.Args())
+		err = vals.Exec(m, execCmd.Args())
 		if err != nil {
 			fatal("%v", err)
 		}
@@ -125,7 +158,10 @@ func main() {
 		execEnv := flag.NewFlagSet(CmdEnv, flag.ExitOnError)
 		f := execEnv.String("f", "", "YAML/JSON file to be loaded to set envvars")
 		export := execEnv.Bool("export", false, "Prepend 'export' to each line")
-		execEnv.Parse(os.Args[2:])
+		err := execEnv.Parse(os.Args[2:])
+		if err != nil {
+			fatal("%v", err)
+		}
 
 		m := readOrFail(f)
 
@@ -143,7 +179,10 @@ func main() {
 		evalCmd := flag.NewFlagSet(CmdKsDecode, flag.ExitOnError)
 		f := evalCmd.String("f", "", "YAML/JSON file to be decoded")
 		o := evalCmd.String("o", "yaml", "Output type which is either \"yaml\" or \"json\"")
-		evalCmd.Parse(os.Args[2:])
+		err := evalCmd.Parse(os.Args[2:])
+		if err != nil {
+			fatal("%v", err)
+		}
 
 		nodes := readNodesOrFail(f)
 
@@ -174,8 +213,7 @@ func KsDecode(node yaml.Node) (*yaml.Node, error) {
 		return nil, fmt.Errorf("unexpected kind of node: expected %d, got %d", yaml.DocumentNode, node.Kind)
 	}
 
-	var res yaml.Node
-	res = node
+	var res yaml.Node = node
 
 	var kk yaml.Node
 	var vv yaml.Node
