@@ -2,15 +2,17 @@ package s3
 
 import (
 	"fmt"
+	"io"
+	"strings"
+
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/service/s3"
 	"github.com/aws/aws-sdk-go/service/s3/s3iface"
-	"github.com/variantdev/vals/pkg/api"
-	"github.com/variantdev/vals/pkg/awsclicompat"
 	"gopkg.in/yaml.v3"
-	"io/ioutil"
-	"os"
-	"strings"
+
+	"github.com/helmfile/vals/pkg/api"
+	"github.com/helmfile/vals/pkg/awsclicompat"
+	"github.com/helmfile/vals/pkg/log"
 )
 
 type provider struct {
@@ -57,9 +59,9 @@ func (p *provider) GetString(key string) (string, error) {
 		return "", fmt.Errorf("getting s3 object: %w", err)
 	}
 
-	p.debugf("s3: successfully retrieved object for key=%s", key)
+	log.Debugf("s3: successfully retrieved object for key=%s", key)
 
-	all, err := ioutil.ReadAll(out.Body)
+	all, err := io.ReadAll(out.Body)
 	if err != nil {
 		return "", fmt.Errorf("reading s3 object body: %w", err)
 	}
@@ -82,10 +84,6 @@ func (p *provider) GetStringMap(key string) (map[string]interface{}, error) {
 	return m, nil
 }
 
-func (p *provider) debugf(msg string, args ...interface{}) {
-	fmt.Fprintf(os.Stderr, msg+"\n", args...)
-}
-
 func (p *provider) getS3Client() s3iface.S3API {
 	if p.s3Client != nil {
 		return p.s3Client
