@@ -10,29 +10,29 @@ import (
 	"strings"
 	"sync"
 
-	"github.com/variantdev/vals/pkg/config"
-	"github.com/variantdev/vals/pkg/providers/googlesheets"
-	"github.com/variantdev/vals/pkg/providers/s3"
-
 	lru "github.com/hashicorp/golang-lru"
-	"github.com/variantdev/vals/pkg/api"
-	"github.com/variantdev/vals/pkg/expansion"
-	"github.com/variantdev/vals/pkg/providers/awskms"
-	"github.com/variantdev/vals/pkg/providers/awssecrets"
-	"github.com/variantdev/vals/pkg/providers/azurekeyvault"
-	"github.com/variantdev/vals/pkg/providers/echo"
-	"github.com/variantdev/vals/pkg/providers/envsubst"
-	"github.com/variantdev/vals/pkg/providers/file"
-	"github.com/variantdev/vals/pkg/providers/gcpsecrets"
-	"github.com/variantdev/vals/pkg/providers/gcs"
-	"github.com/variantdev/vals/pkg/providers/gitlab"
-	"github.com/variantdev/vals/pkg/providers/sops"
-	"github.com/variantdev/vals/pkg/providers/ssm"
-	"github.com/variantdev/vals/pkg/providers/tfstate"
-	"github.com/variantdev/vals/pkg/providers/vault"
-	"github.com/variantdev/vals/pkg/stringmapprovider"
-	"github.com/variantdev/vals/pkg/stringprovider"
 	"gopkg.in/yaml.v3"
+
+	"github.com/helmfile/vals/pkg/api"
+	"github.com/helmfile/vals/pkg/config"
+	"github.com/helmfile/vals/pkg/expansion"
+	"github.com/helmfile/vals/pkg/providers/awskms"
+	"github.com/helmfile/vals/pkg/providers/awssecrets"
+	"github.com/helmfile/vals/pkg/providers/azurekeyvault"
+	"github.com/helmfile/vals/pkg/providers/echo"
+	"github.com/helmfile/vals/pkg/providers/envsubst"
+	"github.com/helmfile/vals/pkg/providers/file"
+	"github.com/helmfile/vals/pkg/providers/gcpsecrets"
+	"github.com/helmfile/vals/pkg/providers/gcs"
+	"github.com/helmfile/vals/pkg/providers/gitlab"
+	"github.com/helmfile/vals/pkg/providers/googlesheets"
+	"github.com/helmfile/vals/pkg/providers/s3"
+	"github.com/helmfile/vals/pkg/providers/sops"
+	"github.com/helmfile/vals/pkg/providers/ssm"
+	"github.com/helmfile/vals/pkg/providers/tfstate"
+	"github.com/helmfile/vals/pkg/providers/vault"
+	"github.com/helmfile/vals/pkg/stringmapprovider"
+	"github.com/helmfile/vals/pkg/stringprovider"
 )
 
 const (
@@ -120,8 +120,8 @@ func New(opts Options) (*Runtime, error) {
 	return r, nil
 }
 
-// Eval replaces 'ref+<provider>://xxxxx' entries by their actual values
-func (r *Runtime) Eval(template map[string]interface{}) (map[string]interface{}, error) {
+// nolint
+func (r *Runtime) prepare() (*expansion.ExpandRegexMatch, error) {
 	var err error
 
 	uriToProviderHash := func(uri *url.URL) string {
@@ -360,6 +360,16 @@ func (r *Runtime) Eval(template map[string]interface{}) (map[string]interface{},
 		},
 	}
 
+	return &expand, nil
+}
+
+// Eval replaces 'ref+<provider>://xxxxx' entries by their actual values
+func (r *Runtime) Eval(template map[string]interface{}) (map[string]interface{}, error) {
+	expand, err := r.prepare()
+	if err != nil {
+		return nil, err
+	}
+
 	ret, err := expand.InMap(template)
 	if err != nil {
 		return nil, err
@@ -368,6 +378,20 @@ func (r *Runtime) Eval(template map[string]interface{}) (map[string]interface{},
 	return ret, nil
 }
 
+// Get replaces every occurrence of 'ref+<provider>://xxxxx' within a string with the fetched value
+func (r *Runtime) Get(code string) (string, error) {
+	expand, err := r.prepare()
+	if err != nil {
+		return "", err
+	}
+
+	ret, err := expand.InString(code)
+	if err != nil {
+		return "", err
+	}
+
+	return ret, nil
+}
 func cloneMap(m map[string]interface{}) map[string]interface{} {
 	bs, err := yaml.Marshal(m)
 	if err != nil {
@@ -456,6 +480,15 @@ func Eval(template map[string]interface{}, o ...Options) (map[string]interface{}
 	return runtime.Eval(template)
 }
 
+func Get(code string) (string, error) {
+	runtime, err := New(Options{})
+	if err != nil {
+		return "", err
+	}
+	return runtime.Get(code)
+}
+
+// nolint
 func Load(conf api.StaticConfig, opt ...Option) (map[string]interface{}, error) {
 	ctx := &ctx{}
 	for _, o := range opt {
